<?php
namespace Quizpalme\Tinyaccordion\Controller;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013 Kurt Gusbeth <info@myquizandpoll.de>
 *  
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * TinyAccordion: Ausgabe der Dokumenten-Auswahl als Accordion
 *
 * @package tinyaccordion
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class SelectionController extends \TYPO3\CMS\Extbase\Mvc\Controller\ActionController {
		
	/**
	 * @var Content Object
	 */
	protected $cObj;

    /**
     * Parse a content element
     *
	 * @param	int			UID of any content element
     * @return 	string		Parsed Content Element
     */
    public function myRender($table, $uid) {
		$conf = array(
			'tables' => $table,
			'source' => $uid,
			'dontCheckPid' => 1
		);
		//return $this->cObj->RECORDS($conf);
		return $this->cObj->cObjGetSingle('RECORDS', $conf);
    }
    
	/**
	 * get the PID(s)
	 *
	 * @return string
	 */
	public function getPidAndInit() {
		$this->cObj = $this->configurationManager->getContentObject();
		
		if( !($this->cObj->data['pages'] == '') ) {
			$pid = addslashes($this->cObj->data['pages']);
		} else {
			// Ordner mit Dokumenten finden
			$res5 = $GLOBALS['TYPO3_DB']->exec_SELECTquery('uid',
					'pages',
					'pid='.intval($GLOBALS['TSFE']->id).' AND doktype=254 ' . $this->cObj->enableFields('pages'),
					'',
					'sorting',
					'1');
			if ($GLOBALS['TYPO3_DB']->sql_num_rows($res5)>0) {
				$row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res5);
				$pid = intval($row['uid']);
			}
			$GLOBALS['TYPO3_DB']->sql_free_result($res5);
		}
		if (!$pid) $pid = intval($GLOBALS['TSFE']->id);
		
	/*	JS-File will be included via TypoScript and page
		if ($this->settings['jsFile']) {
			$datei = str_replace('EXT:tinyaccordion/', t3lib_extMgm::siteRelPath('tinyaccordion'), $this->settings['jsFile']);
			$GLOBALS['TSFE']->additionalHeaderData['tinyaccordion'] = '<script language="JavaScript" type="text/javascript" src="'.$datei.'"></script>';
		} */
	
		return $pid;
	}
	
	/**
	 * action content
	 *
	 * @return void
	 */
	public function contentAction() {
		$pid = $this->getPidAndInit();
		$dataArray = array();
		$noData = TRUE;
		$order = ($this->settings['flexform']['sortorder']=='desc') ? 'DESC' : 'ASC';
		
		// Dokumente holen
		$res5 = $GLOBALS['TYPO3_DB']->exec_SELECTquery('uid, header, tstamp',
				'tt_content',
				'pid IN (' . $pid . ") AND (CType='text' OR CType='textpic' OR CType='textmedia') " . $this->cObj->enableFields('tt_content'),
				'',
				'sorting ' . $order);
		if ($GLOBALS['TYPO3_DB']->sql_num_rows($res5)>0) {
			while($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res5)){
				$dataArray[$row['uid']] = array();
				$dataArray[$row['uid']]['header'] = $row['header'];
				$dataArray[$row['uid']]['datetime'] = $row['tstamp'];
				$noData = FALSE;
			}
		} else $noData = TRUE;
		$GLOBALS['TYPO3_DB']->sql_free_result($res5);
		
		// Dokumente rendern
		if (count($dataArray)>0) {
			foreach ($dataArray as $uid => $value)
				$dataArray[$uid]['bodytext'] = $this->myRender('tt_content', $uid);
		}

		$contentObjectData = $this->configurationManager->getContentObject();
		
		$this->view->assign('elements', $dataArray);
		$this->view->assign('nodata', $noData);
		$this->view->assign('uid', $contentObjectData->data['uid']);
	}
	
	/**
	 * action tt_news
	 *
	 * @return void
	 */
	public function newsAction() {
		$pid = $this->getPidAndInit();
		$dataArray = array();
		$noData = TRUE;
		$childs = 0;
		$order = ($this->settings['flexform']['sortorder']=='desc') ? 'DESC' : 'ASC';
		
		// News+Kategorien holen
		$res5 = $GLOBALS['TYPO3_DB']->exec_SELECTquery('tt_news.uid AS newsid, tt_news.title AS newstitle, tt_news.datetime AS newsdate, cat.uid AS catid, cat.title AS cattitle',
				'tt_news, tt_news_cat AS cat, tt_news_cat_mm AS mm',
				'tt_news.pid IN (' . $pid . ') AND mm.uid_local=tt_news.uid AND mm.uid_foreign=cat.uid' . $this->cObj->enableFields('tt_news'),
				'',
				'cattitle ' . $order . ', tt_news.datetime ' . $order);
		if ($GLOBALS['TYPO3_DB']->sql_num_rows($res5)>0) {
			while($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res5)){
				if (!is_array($dataArray[$row['catid']])) {
					$dataArray[$row['catid']] = array();
					$dataArray[$row['catid']]['news'] = array();
				}
				$dataArray[$row['catid']]['header'] = $row['cattitle'];
				$dataArray[$row['catid']]['news'][$row['newsid']] = array();
				$dataArray[$row['catid']]['news'][$row['newsid']]['header'] = $row['newstitle'];
				$dataArray[$row['catid']]['news'][$row['newsid']]['datetime'] = $row['newsdate'];
				$noData = FALSE;
			}
		} else $noData = TRUE;
		$GLOBALS['TYPO3_DB']->sql_free_result($res5);
			
		// Dokumente rendern
		if (count($dataArray)>0) {
			foreach ($dataArray as $uid => $value) {
				$childs++;
				foreach ($dataArray[$uid]['news'] as $newsid => $newsvalue)
					$dataArray[$uid]['news'][$newsid]['bodytext'] = $this->myRender('tt_news', $newsid);
			}
		}
		
		$contentObjectData = $this->configurationManager->getContentObject();
		
		$this->view->assign('elements', $dataArray);
		$this->view->assign('nodata', $noData);
		$this->view->assign('childs', $childs);
		$this->view->assign('uid', $contentObjectData->data['uid']);
	}

	/**
	 * action tt_news + UI
	 *
	 * @return void
	 */
	public function news_ui_accordionAction() {
		$this->newsAction();
	}

	/**
	 * action news
	 *
	 * @return void
	 */
	public function camaligaAction() {
		$pid = $this->getPidAndInit();
		$dataArray = array();
		$noData = TRUE;
		$childs = 0;
		$order = ($this->settings['flexform']['sortorder']=='desc') ? 'DESC' : 'ASC';
	
		// News+Kategorien holen
		$res5 = $GLOBALS['TYPO3_DB']->exec_SELECTquery('tx_camaliga_domain_model_content.uid AS camid, tx_camaliga_domain_model_content.title AS camtitle, tx_camaliga_domain_model_content.shortdesc, tx_camaliga_domain_model_content.longdesc, tx_camaliga_domain_model_content.link, cat.uid AS catid, cat.title AS cattitle',
				'tx_camaliga_domain_model_content, sys_category AS cat, sys_category_record_mm AS mm',
				'tx_camaliga_domain_model_content.pid IN (' . $pid . ') AND mm.uid_local=cat.uid AND mm.uid_foreign=tx_camaliga_domain_model_content.uid' . $this->cObj->enableFields('tx_camaliga_domain_model_content'),
				'',
				'tx_camaliga_domain_model_content.sorting ' . $order);
		if ($GLOBALS['TYPO3_DB']->sql_num_rows($res5)>0) {
			while($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res5)){
				if (!is_array($dataArray[$row['catid']])) {
					$dataArray[$row['catid']] = array();
					$dataArray[$row['catid']]['camaliga'] = array();
				}
				$dataArray[$row['catid']]['header'] = $row['cattitle'];
				$dataArray[$row['catid']]['camaliga'][$row['camid']] = array();
				$dataArray[$row['catid']]['camaliga'][$row['camid']]['header'] = $row['camtitle'];
				$dataArray[$row['catid']]['camaliga'][$row['camid']]['shortdesc'] = $row['shortdesc'];
				$dataArray[$row['catid']]['camaliga'][$row['camid']]['longdesc'] = $row['longdesc'];
				$dataArray[$row['catid']]['camaliga'][$row['camid']]['link'] = $row['link'];
				$noData = FALSE;
			}
		} else $noData = TRUE;
		$GLOBALS['TYPO3_DB']->sql_free_result($res5);
	
		$contentObjectData = $this->configurationManager->getContentObject();
	
		$this->view->assign('elements', $dataArray);
		$this->view->assign('nodata', $noData);
		$this->view->assign('childs', $childs);
		$this->view->assign('uid', $contentObjectData->data['uid']);
	}

	/**
	 * action Camaliga + UI
	 *
	 * @return void
	 */
	public function camaliga_ui_accordionAction() {
		$this->camaligaAction();
	}
}
?>